# npqtools


Данная Python-библиотека создана для решения популярных NP-сложных задач, таких как:
* Задача коммивояжера
* Задача о рюкзаке
* Задача о поиске Гамильтонова цикла
* Задача о поиске клики в неориентированном графе
* Задача о распределении ограниченных ресурсов проекта

И другие

Решение производится с помощью симуляции квантового отжига в решении QUBO.


